# OPS05-BP06: Share design standards

## Description

Chia sẻ và enforce design standards across teams.

## Implementation Guidance

- Architecture Decision Records (ADRs)
- Design guidelines documented
- Shared libraries and templates
- Regular architecture reviews
- Standards enforcement in reviews

## Risk Level

Low - Inconsistent standards lead to maintenance burden.
